@@ -1,7 +1,7 @@
 /*
  * ComputerControlInterface.h - interface class for controlling a computer
  *
- * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -31,6 +31,7 @@
 
 #include "Computer.h"
 #include "Feature.h"
+#include "Lockable.h"
 #include "VeyonCore.h"
 #include "VncConnection.h"
 
@@ -41,7 +42,7 @@ class FeatureMessage;
 class VncConnection;
 class VeyonConnection;
 
-class VEYON_CORE_EXPORT ComputerControlInterface : public QObject
+class VEYON_CORE_EXPORT ComputerControlInterface : public QObject, public Lockable
 {
 	Q_OBJECT
 public:
@@ -115,7 +116,12 @@ public:
 		return m_designatedModeFeature;
 	}
 
-	void setDesignatedModeFeature( Feature::Uid designatedModeFeature );
+	void setDesignatedModeFeature( Feature::Uid designatedModeFeature )
+	{
+		m_designatedModeFeature = designatedModeFeature;
+	}
+
+	void updateActiveFeatures();
 
 	void sendFeatureMessage( const FeatureMessage& featureMessage, bool wake );
 	bool isMessageQueueEmpty();
@@ -134,7 +140,6 @@ private:
 
 	void updateState();
 	void updateUser();
-	void updateActiveFeatures();
 
 	void handleFeatureMessage( const FeatureMessage& message );
 
