@@ -1,7 +1,7 @@
 /*
  * FeatureManager.h - header for the FeatureManager class
  *
- * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -55,21 +55,23 @@ public:
 	void controlFeature( Feature::Uid featureUid,
 						FeatureProviderInterface::Operation operation,
 						const QVariantMap& arguments,
-						const ComputerControlInterfaceList& computerControlInterfaces );
+						const ComputerControlInterfaceList& computerControlInterfaces ) const;
 
 	void startFeature( VeyonMasterInterface& master,
 					   const Feature& feature,
-					   const ComputerControlInterfaceList& computerControlInterfaces );
+					   const ComputerControlInterfaceList& computerControlInterfaces ) const;
 	void stopFeature( VeyonMasterInterface& master,
 					  const Feature& feature,
-					  const ComputerControlInterfaceList& computerControlInterfaces );
+					  const ComputerControlInterfaceList& computerControlInterfaces ) const;
+
+	void updateActiveFeatures( const ComputerControlInterfaceList& computerControlInterfaces ) const;
 
 	bool handleFeatureMessage( ComputerControlInterface::Pointer computerControlInterface,
-							  const FeatureMessage& message );
+							  const FeatureMessage& message ) const;
 	bool handleFeatureMessage( VeyonServerInterface& server,
 							   const MessageContext& messageContext,
-							   const FeatureMessage& message );
-	bool handleFeatureMessage( VeyonWorkerInterface& worker, const FeatureMessage& message );
+							   const FeatureMessage& message ) const;
+	bool handleFeatureMessage( VeyonWorkerInterface& worker, const FeatureMessage& message ) const;
 
 private:
 	FeatureList m_features;
