@@ -1,7 +1,7 @@
 /*
  * ComputerControlInterface.cpp - interface class for controlling a computer
  *
- * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -204,11 +204,20 @@ void ComputerControlInterface::setActiveFeatures( const FeatureUidList& activeFe
 
 
 
-void ComputerControlInterface::setDesignatedModeFeature( Feature::Uid designatedModeFeature )
+void ComputerControlInterface::updateActiveFeatures()
 {
-	m_designatedModeFeature = designatedModeFeature;
+	lock();
 
-	updateActiveFeatures();
+	if( m_vncConnection && m_connection && state() == State::Connected )
+	{
+		VeyonCore::builtinFeatures().featureControl().queryActiveFeatures( { weakPointer() } );
+	}
+	else
+	{
+		setActiveFeatures( {} );
+	}
+
+	unlock();
 }
 
 
@@ -301,6 +310,8 @@ void ComputerControlInterface::restartConnection()
 
 void ComputerControlInterface::updateState()
 {
+	lock();
+
 	if( m_vncConnection )
 	{
 		switch( m_vncConnection->state() )
@@ -318,12 +329,16 @@ void ComputerControlInterface::updateState()
 	{
 		m_state = State::Disconnected;
 	}
+
+	unlock();
 }
 
 
 
 void ComputerControlInterface::updateUser()
 {
+	lock();
+
 	if( m_vncConnection && m_connection && state() == State::Connected )
 	{
 		if( userLoginName().isEmpty() )
@@ -335,20 +350,8 @@ void ComputerControlInterface::updateUser()
 	{
 		setUserInformation( {}, {}, -1 );
 	}
-}
 
-
-
-void ComputerControlInterface::updateActiveFeatures()
-{
-	if( m_vncConnection && m_connection && state() == State::Connected )
-	{
-		VeyonCore::builtinFeatures().featureControl().queryActiveFeatures( { weakPointer() } );
-	}
-	else
-	{
-		setActiveFeatures( {} );
-	}
+	unlock();
 }
 
 
