@@ -1,7 +1,7 @@
 /*
  * FeatureManager.cpp - implementation of the FeatureManager class
  *
- * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -118,19 +118,21 @@ Plugin::Uid FeatureManager::pluginUid( const Feature& feature ) const
 void FeatureManager::controlFeature( Feature::Uid featureUid,
 									FeatureProviderInterface::Operation operation,
 									const QVariantMap& arguments,
-									const ComputerControlInterfaceList& computerControlInterfaces )
+									const ComputerControlInterfaceList& computerControlInterfaces ) const
 {
 	for( auto featureInterface : qAsConst( m_featurePluginInterfaces ) )
 	{
 		featureInterface->controlFeature( featureUid, operation, arguments, computerControlInterfaces );
 	}
+
+	updateActiveFeatures( computerControlInterfaces );
 }
 
 
 
 void FeatureManager::startFeature( VeyonMasterInterface& master,
 								   const Feature& feature,
-								   const ComputerControlInterfaceList& computerControlInterfaces )
+								   const ComputerControlInterfaceList& computerControlInterfaces ) const
 {
 	vDebug() << "feature" << feature.name() << feature.uid() << computerControlInterfaces;
 
@@ -146,13 +148,15 @@ void FeatureManager::startFeature( VeyonMasterInterface& master,
 			controlInterface->setDesignatedModeFeature( feature.uid() );
 		}
 	}
+
+	updateActiveFeatures( computerControlInterfaces );
 }
 
 
 
 void FeatureManager::stopFeature( VeyonMasterInterface& master,
 								  const Feature& feature,
-								  const ComputerControlInterfaceList& computerControlInterfaces )
+								  const ComputerControlInterfaceList& computerControlInterfaces ) const
 {
 	vDebug() << "feature" << feature.name() << feature.uid() << computerControlInterfaces;
 
@@ -168,14 +172,26 @@ void FeatureManager::stopFeature( VeyonMasterInterface& master,
 			controlInterface->setDesignatedModeFeature( Feature::Uid() );
 		}
 	}
+
+	updateActiveFeatures( computerControlInterfaces );
+}
+
+
+
+void FeatureManager::updateActiveFeatures( const ComputerControlInterfaceList& computerControlInterfaces ) const
+{
+	for( const auto& controlInterface : computerControlInterfaces )
+	{
+		controlInterface->updateActiveFeatures();
+	}
 }
 
 
 
 bool FeatureManager::handleFeatureMessage( ComputerControlInterface::Pointer computerControlInterface,
-										  const FeatureMessage& message )
+										  const FeatureMessage& message ) const
 {
-	vDebug() << "feature" << message.featureUid()
+	vDebug() << "feature" << feature(message.featureUid()).name()
 			 << "command" << message.command()
 			 << "arguments" << message.arguments();
 
@@ -196,9 +212,9 @@ bool FeatureManager::handleFeatureMessage( ComputerControlInterface::Pointer com
 
 bool FeatureManager::handleFeatureMessage( VeyonServerInterface& server,
 										   const MessageContext& messageContext,
-										   const FeatureMessage& message )
+										   const FeatureMessage& message ) const
 {
-	vDebug() << "feature" << message.featureUid()
+	vDebug() << "feature" << feature(message.featureUid()).name()
 			 << "command" << message.command()
 			 << "arguments" << message.arguments();
 
@@ -223,9 +239,9 @@ bool FeatureManager::handleFeatureMessage( VeyonServerInterface& server,
 
 
 
-bool FeatureManager::handleFeatureMessage( VeyonWorkerInterface& worker, const FeatureMessage& message )
+bool FeatureManager::handleFeatureMessage( VeyonWorkerInterface& worker, const FeatureMessage& message ) const
 {
-	vDebug() << "feature" << message.featureUid()
+	vDebug() << "feature" << feature(message.featureUid()).name()
 			 << "command" << message.command()
 			 << "arguments" << message.arguments();
 
