@@ -1,7 +1,7 @@
 /*
  * VncView.cpp - abstract base for all VNC views
  *
- * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2021 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -22,9 +22,8 @@
  *
  */
 
-#define XK_KOREAN
-#include "rfb/keysym.h"
-#include "rfb/rfbproto.h"
+#include <rfb/keysym.h>
+#include <rfb/rfbproto.h>
 
 #include <QCursor>
 #include <QHoverEvent>
