@@ -1,7 +1,7 @@
 /*
  * ScreenshotManagementPanel.cpp - implementation of screenshot management view
  *
- * Copyright (c) 2004-2020 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2004-2021 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -43,7 +43,7 @@ ScreenshotManagementPanel::ScreenshotManagementPanel( QWidget *parent ) :
 
 	VeyonCore::filesystem().ensurePathExists( VeyonCore::config().screenshotDirectory() );
 
-	m_fsWatcher.addPath( VeyonCore::config().screenshotDirectory() );
+	m_fsWatcher.addPath( VeyonCore::filesystem().screenshotDirectoryPath() );
 	connect( &m_fsWatcher, &QFileSystemWatcher::directoryChanged, this, &ScreenshotManagementPanel::updateModel );
 
 	m_reloadTimer.setInterval( FsModelResetDelay );
