@@ -1,7 +1,7 @@
 /*
  * DemoFeaturePlugin.cpp - implementation of DemoFeaturePlugin class
  *
- * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -172,7 +172,7 @@ bool DemoFeaturePlugin::startFeature( VeyonMasterInterface& master, const Featur
 			return true;
 		}
 
-		auto vncServerPort = VeyonCore::config().vncServerPort();
+		auto vncServerPortOffset = 0;
 		auto demoServerPort = VeyonCore::config().demoServerPort();
 
 		const auto demoServerInterface = master.selectedComputerControlInterfaces().first();
@@ -182,14 +182,14 @@ bool DemoFeaturePlugin::startFeature( VeyonMasterInterface& master, const Featur
 		if( primaryServerPort > 0 )
 		{
 			const auto sessionId = primaryServerPort - VeyonCore::config().veyonServerPort();
-			vncServerPort += sessionId;
+			vncServerPortOffset = sessionId;
 			demoServerPort += sessionId;
 		}
 
 		// start demo server
 		controlFeature( m_demoServerFeature.uid(), Operation::Start,
 						{
-							{ argToString(Argument::VncServerPort), vncServerPort },
+							{ argToString(Argument::VncServerPortOffset), vncServerPortOffset },
 							{ argToString(Argument::DemoServerPort), demoServerPort },
 						},
 						master.selectedComputerControlInterfaces() );
@@ -233,7 +233,7 @@ bool DemoFeaturePlugin::stopFeature( VeyonMasterInterface& master, const Feature
 		feature == m_shareOwnScreenWindowFeature || feature == m_shareOwnScreenFullScreenFeature ||
 		feature == m_shareUserScreenWindowFeature || feature == m_shareUserScreenFullScreenFeature )
 	{
-		controlFeature( feature.uid(), Operation::Stop, {}, computerControlInterfaces );
+		controlFeature( m_demoClientWindowFeature.uid(), Operation::Stop, {}, computerControlInterfaces );
 
 		controlFeature( m_demoClientWindowFeature.uid(), Operation::Stop, {},
 						{ master.localSessionControlInterface().weakPointer() } );
@@ -271,7 +271,8 @@ bool DemoFeaturePlugin::handleFeatureMessage( VeyonServerInterface& server,
 			server.featureWorkerManager().
 				sendMessageToManagedSystemWorker(
 					FeatureMessage{ message }
-						.addArgument( Argument::VncServerPassword, VeyonCore::authenticationCredentials().internalVncServerPassword().toByteArray() ) );
+						.addArgument( Argument::VncServerPassword, VeyonCore::authenticationCredentials().internalVncServerPassword().toByteArray() )
+						.addArgument( Argument::VncServerPort, server.vncServerBasePort() + message.argument(Argument::VncServerPortOffset).toInt() ) );
 		}
 		else if( message.command() != StopDemoServer ||
 				 server.featureWorkerManager().isWorkerRunning( m_demoServerFeature.uid() ) )
@@ -507,10 +508,17 @@ QRect DemoFeaturePlugin::viewportFromScreenSelection() const
 		return {};
 	}
 
+	QPoint minimumScreenPosition{};
+	for( const auto* screen : m_screens )
+	{
+		minimumScreenPosition.setX( qMin( minimumScreenPosition.x(), screen->geometry().x() ) );
+		minimumScreenPosition.setY( qMin( minimumScreenPosition.y(), screen->geometry().y() ) );
+	}
+
 	const auto screen = m_screens.value( m_screenSelection - 1 );
 	if( screen )
 	{
-		return screen->geometry();
+		return screen->geometry().translated( -minimumScreenPosition );
 	}
 
 	return {};
@@ -525,14 +533,14 @@ bool DemoFeaturePlugin::controlDemoServer( Operation operation, const QVariantMa
 	{
 		const auto demoServerPort = arguments.value( argToString(Argument::DemoServerPort),
 													 VeyonCore::config().demoServerPort() + VeyonCore::sessionId() ).toInt();
-		const auto vncServerPort = arguments.value( argToString(Argument::VncServerPort),
-													VeyonCore::config().vncServerPort() + VeyonCore::sessionId() ).toInt();
+		const auto vncServerPortOffset = arguments.value( argToString(Argument::VncServerPortOffset),
+														  VeyonCore::sessionId() ).toInt();
 		const auto demoAccessToken = arguments.value( argToString(Argument::DemoAccessToken),
 													  m_demoAccessToken.toByteArray() ).toByteArray();
 
 		sendFeatureMessage( FeatureMessage{ m_demoServerFeature.uid(), StartDemoServer }
 								.addArgument( Argument::DemoAccessToken, demoAccessToken )
-								.addArgument( Argument::VncServerPort, vncServerPort )
+								.addArgument( Argument::VncServerPortOffset, vncServerPortOffset )
 								.addArgument( Argument::DemoServerPort, demoServerPort ),
 							computerControlInterfaces );
 
