@@ -1,7 +1,7 @@
 /*
  * DemoFeaturePlugin.h - declaration of DemoFeaturePlugin class
  *
- * Copyright (c) 2017-2020 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -53,7 +53,8 @@ public:
 		ViewportX,
 		ViewportY,
 		ViewportWidth,
-		ViewportHeight
+		ViewportHeight,
+		VncServerPortOffset
 	};
 	Q_ENUM(Argument)
 
