@@ -1,7 +1,7 @@
 /*
  * ComputerControlServer.h - header file for ComputerControlServer
  *
- * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2021 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -70,6 +70,10 @@ public:
 		return m_featureWorkerManager;
 	}
 
+	int vncServerBasePort() const override
+	{
+		return m_vncServer.serverBasePort();
+	}
 
 private:
 	void checkForIncompleteAuthentication( VncServerClient* client );
