@@ -2,7 +2,7 @@
  * VncServer.cpp - implementation of VncServer, a VNC-server-
  *                      abstraction for platform independent VNC-server-usage
  *
- * Copyright (c) 2006-2020 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2021 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -105,14 +105,22 @@ void VncServer::prepare()
 
 
 
-int VncServer::serverPort() const
+int VncServer::serverBasePort() const
 {
+
 	if( m_pluginInterface && m_pluginInterface->configuredServerPort() > 0 )
 	{
-		return m_pluginInterface->configuredServerPort() + VeyonCore::sessionId();
+		return m_pluginInterface->configuredServerPort();
 	}
 
-	return VeyonCore::config().vncServerPort() + VeyonCore::sessionId();
+	return VeyonCore::config().vncServerPort();
+}
+
+
+
+int VncServer::serverPort() const
+{
+	return serverBasePort() + VeyonCore::sessionId();
 }
 
 
